---
title: "The Declaration of Independence, Part 2: Self-Evident Truths"
date: 2020-07-02T20:47:03Z
tags: ["unalienable rights","natural law","consent of the governed"]
topics: ["philosophy","politics"]
image: /img/jefferson-and-locke.jpg
draft: false
---

> *We hold these truths to be self-evident, that all men are created equal, that they are endowed by their Creator with certain unalienable rights, that among these are life, liberty, and the pursuit of happiness. That, to secure these rights, governments are instituted among men, deriving their just powers from the consent of the governed. That, whenever any form of government becomes destructive of these ends, it is the right of the people to alter or to abolish it, and to institute new government, laying its foundation on such principles, and organizing its powers in such form, as to them shall seem most likely to effect their safety and happiness.*

This is, of course, the passage that everyone is (more or less) familiar with — at least the first sentence. In the United States, the first sentence has been crystalized into a kind of religious creed, similar in tone and meter to opening lines of the Apostle’s Creed: “We believe in one God, the Father almighty, creator of heaven and earth…”, and so forth. But Jefferson had *philosophical* notions in mind when he wrote this, however pious he may (or may not) have been. To understand what’s going on in this paragraph, I’ll need to break it into multiple pieces, beginning with the very first word, and ending with dissolution.

**We, The People**

So, who exactly, is the “we” that Jefferson presumes to be speaking for? There are two schools of thought on this question. First (the Bailyn argument), that Jefferson and his compatriots were republican (small “r”) partisans, who sought to divest themselves of English rule, on account of its incorrigible corruption, and in pursuit of a more virtuous government. There is some evidence for this. For example, this snippet from a letter Jefferson wrote to Richard Henry Lee, in 1825 (a year before his death):

> “…with respect to our rights, and the acts of the British government contravening those rights, there was but one opinion on this side of the water. All American Whigs thought alike on these subjects…”

But it is equally as plausible that he was referring, at the time, to the “common good” idea of the “we”, found both in Locke and in Rousseau. Given the overwhelmingly obvious parallels in the language between the Declaration and Locke’s second Treatise (and Enquiry Concerning Human Understanding), I am inclined to take this interpretation. But it’s still entirely possible that Jefferson was simply conflating his identification with the Whigs, as synonymous with the “general will”.

**The American Mind**

In any case, what follows the “we” is an assertion of axiomatic (arguably dogmatic) commitment to Locke’s conception of natural rights, as set out in his Second Treatise on Government, and Enquiry Concerning Human Understanding. Jefferson admits as much, himself, in the same letter to Lee:

> *“…This was the object of the Declaration of Independence. Not to find out new principles, or new arguments, never before thought of, not merely to say things which had never been said before; but to place before mankind the common sense of the subject, in terms so plain and firm as to command their assent, and to justify ourselves in the independent stand we are compelled to take. Neither aiming at originality of principle or sentiment, nor yet copied from any particular and previous writing, it was intended to be an expression of the American mind, and to give that expression the proper tone and spirit called for by the occasion. **All its authority rests then on the harmonizing sentiments of the day, whether expressed in conversation, in letters, in printed essays, or in the elementary books of public right, as Aristotle, Cicero, Locke, Sidney**, etc…”*

If Jefferson himself says his influences were Aristotle and Locke, who am I to object? In fact, a battle still rages in both political philosophy and academic history, over whether Aristotle or Locke was the more important influence to the founders in the formation of the American republic (and, is in fact the source of the division between Liberals and Conservatives in America). But one thing is certain: Locke is the star of the show in the Declaration of Independence.

**Self-Evidence**

Before moving on to the enumeration of unalienable rights, I want to briefly pause here to explore the idea of “self-evident” truth. The one-line dictionary definition of this term is “*evident without proof or demonstration; axiomatic*“. It is tempting to interpret Jefferson’s use of this term in a theological way. As in, truths that are known by the grace of God, or by special revelation or beatific vision. It is also tempting to imagine that Jefferson had in mind some sort of Cartesian notion of “*clear and distinct ideas*“, in which no syllogistic steps were necessary to arrive at a single piece of firm knowledge (e.g. “cogito, ergo sum”).

The story is actually much simpler than that, I’m afraid, and it is confessed again, in that snippet to Lee: 

> “…*the common sense of the subject, in terms so plain and firm as to command their assent*…”. In other words, Jefferson and his colleagues were stating what they took to be the commonly accepted, received wisdom of the day, as simply axiomatic. In modern terms then, the opening of this paragraph might have been written, “*We take the following things to be well-established common sense among politically thoughtful people*…”

In short: they took Locke and Cicero to be the equivalent of *average common sense*, in 1776. Let that sink in.

**Unalienable Rights**

Sometimes it is fashionable to point to the “pursuit of happiness” as a divergence from Locke, who in the Second Treatise, used the term “property” in connection with the other two “unalienables”. But both Locke and Jefferson considered it synonymous with “property,” when property is conceived in a broad sense, rather than simply as the ownership of material goods. Locke puts it this way, when explaining the origin of the contract, in chapter IX of the Second Treatise:

> “…*though in the State of Nature [each man] hath such a right [to absolute freedom], yet the enjoyment of it is very uncertain, and constantly exposed to the invasion of others. For all being kings as much as he, every man his equal, and the greater part no strict observers of equity and justice, the enjoyment of the property he has in this State is very unsafe, very unsecure. This makes him willing to quit this condition, which however free, is full of fears and continual dangers: And ’tis not without reason, that he seeks out, and is willing to joyn in society with others who are already united, or have a mind to unite for the mutual **preservation of their Lives, Liberties and Estates, which I call by the general name, Property***…”

And again a bit later, he reiterates:

> “…*By Property I must be understood here, as in other places, to mean that property which men have in their persons as well as goods*…”

So, all three of the “unalienable rights” enumerated in the Declaration are “properties” of man. In the sense that lead has the property of high density and high malleability, man has life and the liberty to pursue the fulfillment of that life, because God has endowed these things to man. Indeed, as I mentioned in another essay, Locke goes so far as to insist that being ultimately the property of God, we are all individually bound by the curse of Adam to strive for a good life. So, the properties are more than material facts, they are *moral facts*. Which is to say, these properties confer not just causal powers, but *moral powers*. We are granted the liberty to exercise certain powers, so that we can fulfill the duty imposed upon us by nature’s Creator.

One more thing must be said about this. Today it is fashionable to think that the “right to life” means literally that one is entitled to be alive, or to have a life. Even on Locke’s conception, this cannot be the case. God grants us life as a *gift*, not an *entitlement*. For Locke, we all serve at His pleasure, not our own. But, once granted, no man has the authority to rescind the gift, not even oneself (which is one of the reasons Locke opposed slavery and indentured servitude). So, the right to life is really only the right not to have one’s life taken away by other men (either by forced labor or by death), not an entitlement to living (or any particular life), in any absolute sense.

**To Secure These Rights**

Continuing the list of axiomatic commitments, Jefferson goes on to summarize Locke’s theory of social contract. You can see it in the quote above, but just to resummarize, in a state of nature, we have “natural rights”, but the state of nature leaves no means by which to defend those rights. So, we join together in a society, and create institutions that are meant to function collectively as the machinery of preservation. But the key phrase of interest in this passage is, “the consent of the governed”. This too, comes directly from Locke (though, to be fair, it is conceptually present in Hobbes, Rousseau, and many classical writers like Cicero – who Jefferson mentions as well):

> “…Men are naturally free, and the Examples of History shewing, that the Governments of the World, that were begun in Peace, had their beginning laid on that foundation, and were **made by the Consent of the People**;..”

Locke is making a moral claim from a historical argument, here: “This is how it’s always been done”. That is typical of the English. It’s the basis of the concept of “Common Law”, and our own American principle of Stare Decisis. Unless you have a really good reason to do something differently, you stick with what you know already. You can see this sentiment echoed, again, in that Jefferson letter snippet, and indeed in the next paragraph of the Declaration itself. But this question of the “consent of the governed” is more conceptually complex than either Locke or Jefferson are willing to admit, here (or, for that matter, anywhere in Locke’s writings).

What does it mean to have the “consent” of the “governed”? Rousseau argued that, to be considered consent at all, it must be unanimous. Only when all of the people, without exception, concede to some proposition which places them subordinate to a governing body, is proper consent acquired. This is prior to any institution of decision-making authority like democratic voting, for example. It is only once this unanimous consent is aquired, that we can even begin to negotiate what form the government should take. Hobbes imagines something similar, only instead of mutual concern, the motivation is simply the terror of lawlessness. Locke’s view, as vague as it is, seems to be that all right-thinking people, once shown the utility of a just government, would simply consent to it. So, up-front consent is not really needed, because you can demonstrate that utility at any time. Jefferson and his compatriots appear to take this approach, as well.

But early American history is littered with examples of ostensibly rational people who did not see the utility of the separatist project. In fact, about a third of the colonists were vehement Royalists. Many of them were forced to flee to Canada, when the war for independence broke out. They had to surrender large estates and lost fortunes, in the process. Some even lost their lives. It is one of the tragic paradoxes of the liberal nation-state, that it must violate its own principles, in order to establish and defend itself. To “We, the people”, is attached the addendum, “who happen to accept the new political regime”. Which gets us to the next clause…

**To Alter Or Abolish**

If the revolutionary colonists are to establish a new contract amongst themselves, they need to be able to explain how it is that the old contract with the British people can be justly dissolved. Having established the duty purpose of a just government (to secure the natural rights of the governed), Jefferson logically concludes from this, that the failure to meet this duty is tantamount to invalidating the contract. But Locke makes an interesting point that suggests a justification may be irrelevant in some circumstances:

> …*He that will with any clearness speak of the dissolution of government, ought, in the first place to distinguish between the dissolution of the society, and the dissolution of the government. That which makes the community, and brings men out of the loose State of Nature, into one politick society, is the agreement which every one has with the rest to incorporate, and act as one body, and so be one distinct commonwealth… there wants not much argument to prove, that where the society is dissolved, the government cannot remain; that being as impossible, as for the frame of a house to subsist when the materials of it are scattered, and dissipated by a whirlwind, or jumbled into a confused heap by an earthquake*…

One could argue that, by virtue of the growing disconnect between the American colonies and the British homeland, the *society* had already dissolved. This is roughly the case that Bernard Bailyn makes in his book. If that was the case, then Jefferson was simply pronouncing the patient dead on the table, with the Declaration, rather than justifying a killing. Still, Locke does indeed provide an argument for dissolution “from within”, that Jefferson cribs for this passage in the Declaration:

> …*For, since it can never be supposed to be the Will of the Society that the legislative should have a power to destroy that which every one designs to secure by entering into society, and for which the people submitted themselves to the legislators of their own making; whenever the legislators endeavour to take away, and destroy the property of the people, or to reduce them to slavery under arbitrary power, they put themselves into a state of war with the people, who are thereupon absolved from any farther obedience, and are left to the common refuge, which God hath provided for all men, against force and Violence. Whensoever therefore the legislative shall transgress this fundamental rule of society; and either by ambition, fear, folly or corruption, endeavour to grasp themselves, or put into the hands of any other an absolute power over the lives, liberties, and estates of the people; by this breach of trust **they forfeit the power the people had put into their hands for quite contrary ends, and it devolves to the people, who have a right to resume their original liberty, and, by the establishment of a new legislative (such as they shall think fit) provide for their own safety and security**, which is the end for which they are in society*…

The highlighted passage points to the language that Jefferson borrows, and gives us an actual argument for why the dissolution is justified: we don’t institute governments in order that they may trample on our natural rights, we institute them in order that they may protect them in some fundamental way. So, any institution that would “transgress” this purpose ceases to be an institution of government, and becomes an institution of tyranny. The latter being illegitimate, the people are free to throw it off.

But, Jefferson knows that even this is not enough. He cannot simply assert that George III has transgressed the duties of natural right, he has to demonstrate it with reasons. So, to make that case, the remainder of the document is literally a catalogue of grievances against the crown.

For this, you will have to wait for part three.
