---
title: "On the Freedom of Speech and the Press"
author: "Benjamin Franklin"
image: /img/benjamin-franklin1.jpg
era: "Early Modern"
topic: "Free Speech"
draft: false
---

ON FREEDOM OF SPEECH AND THE PRESS (Published 1839, Harper & Brothers) [Spellings modernized, and footnotes renumbered to flow independently of the rest of the book]

Freedom of speech is a principal pillar of a free government: when this support is taken away, the constitution of a free society is dissolved, and tyranny is erected on its ruins. Republics and limited monarchies derive their strength and vigor from a popular examination into the actions of the magistrates; this privilege, in all ages, has been, and always will be, abused. The best of men could not escape the censure and envy of the times they lived in. Yet this evil is not so great as it may appear at first sight. A magistrate who sincerely aims at the good of society will always have the inclinations of a great majority on his side, and an impartial posterity will not fail to render him justice.

Those abuses of the freedom of speech are the exercises of liberty. They ought to be repressed; but to whom dare we commit the care of doing it? An evil magistrate, entrusted with power to *punish for words*, would be armed with a weapon the most destructive and terrible. Under pretense of pruning off the exuberant branches, he would be apt to destroy the tree.

It is certain that he who robs another of his moral reputation, more richly merits a gibbet than if he had plundered him of his purse on the highway. *Augustus Cæsar*, under the specious pretext of preserving the character of the Romans from defamation, introduced the law whereby libeling was involved in the penalties of treason against the state. This law established his tyranny; and for one mischief which it prevented, ten thousand evils, horrible and afflicting, sprung up in its place. Thenceforward every person’s life and fortune depended on the vile breath of informers. The construction of words being arbitrary, and left to the decision of the judges, no man could write or open his mouth without being in danger of forfeiting his head.

One was put to death for inserting in his history the praises of Brutus. Another for styling Cassius the last of the Romans. Caligula valued himself for being a notable dancer; and to deny that he excelled in that manly accomplishment was high treason. This emperor raised his horse, the name of which was *Incitatus*, to the dignity of consul; and though history is silent, I do not question but it was a capital crime to show the least contempt for that high officer of state! Suppose, then, any one had called the prime minister a *stupid animal*, the emperor’s council might argue that the malice of the libel was the more aggravated by its being true, and, consequently, more likely to excite the *family of this illustrious magistrate* to a breach of the peace or to acts of revenge. Such a prosecution would to us appear ridiculous; yet, if we may rely upon tradition, there have been formerly proconsuls in America, though of more malicious dispositions, hardly superior in understanding to the consul *Incitatus*, and who would have thought themselves libeled to be called by their *proper names*.

*Nero* piqued himself on his fine voice and skill in music: no doubt a laudable ambition! He performed in public, and carried the prize of excellence. It was afterward resolved by all the judges as good law, that whosoever would *insinuate* the least doubt of Nero’s pre-eminence in the *noble art of fiddling* ought to be deemed a traitor to the state.

By the help of inferences and innuendoes, treasons multiplied in a prodigious manner. Grief was treason: a lady of noble birth was put to death for bewailing the death of her *murdered son*: silence was declared an *overt act* to prove the treasonable purposes of the heart: looks were construed into treason: a serene, open aspect was an evidence that the person was pleased with the calamities that befell the emperor: a severe, thoughtful countenance was urged against the man that wore it as a proof of his plotting against the state: *dreams* were often made capital offenses. A new species of informers went about Rome, insinuating themselves into all companies to fish out their dreams, which the priests (oh nefarious wickedness!) interpreted into high treason. The Romans were so terrified by this strange method of juridical and penal process, that, far from discovering their dreams, they durst not own that they slept. In this terrible situation, when every one had so much cause to fear, even *fear* itself was made a crime. Caligula, when he put his brother to death, gave it as a reason to the Senate that the youth was afraid of being murdered. To be eminent in any virtue, either civil or military, was the greatest crime a man could be guilty of. *O virtutes certissemum exitium.*[^1]

These were some of the effects of the Roman law against libeling: those of the British kings that aimed at despotic power or the oppression of the subject, continually encouraged prosecutions for words.

Henry VII., a prince mighty in politics, procured that act to be passed whereby the jurisdiction of the Star Chamber was confirmed and extended. Afterward Empson and Dudley, two voracious dogs of prey, under the protection of this high court, exercised the most merciless acts of oppression. The subjects were terrified from uttering their griefs while they saw the thunder of the Star Chamber pointed at their heads. This caution, however, could not prevent several dangerous tumults and insurrections; for when the tongues of the people are restrained, they commonly discharge their resentments by a more dangerous organ, and break out into open acts of violence.

During the reign of Henry VIII., a high-spirited monarch! every light expression which happened to displease him was construed by his supple judges into a libel, and sometimes extended to high treason. When Queen Mary, of cruel memory, ascended the throne, the Parliament, in order to raise a *fence* against the violent prosecutions for words, which had rendered the lives, liberties, and properties of all men precarious, and, perhaps, dreading the furious persecuting spirit of this princess, passed an act whereby it was declared, “That if a libeler doth go so high as to libel against king or queen by denunciation, the judges shall lay no greater fine on him than one hundred pounds, with two months’ imprisonment, and no corporeal punishment: neither was this sentence to be passed on him except the accusation was fully proved by two witnesses, who were to produce a certificate of their good demeanor for the credit of their report.”

This act was confirmed by another, in the seventh year of the reign of Queen Elizabeth; only the penalties were heightened to two hundred pounds and three months’ imprisonment. Notwithstanding she rarely punished invectives, though the malice of the papists was indefatigable in blackening the brightest characters with the most impudent falsehoods, she was often heard to applaud that rescript of *Theodosius*. If any person spoke ill of the emperor through a foolish rashness and inadvertence, it is to be despised; if out of madness, it deserves pity; if from malice and aversion, it calls for mercy.

Her successor, King James I., was a prince of a quite different genius and disposition; he used to say, that while he had the power of making judges and bishops, *he could have what law and gospel he pleased*. Accordingly, he filled those places with such as prostituted their professions to his notions of prerogative. Among this number, and I hope it is no discredit to the profession of the law, its great oracle, *Sir Edward Coke*, appears. The Star Chamber, which in the time of Elizabeth had gained a good repute, became an intolerable grievance in the reign of this *learned monarch*.

But it did not arrive at its meridian altitude till Charles I. began to wield the sceptre. As he had formed a design to lay aside parliaments and subvert the popular part of the constitution, he very well knew that the form of government could not be altered without laying a restraint on freedom of speech and the liberty of the press: therefore he issued his royal mandate, under the great seal of England, whereby he commanded his subjects, under pain of his displeasure, not to prescribe to him any time for parliaments. Lord Clarendon, upon this occasion, is pleased to write, “That all men took themselves to be prohibited, under the penalty of censure (the censure of the Star Chamber), which few men cared to incur, so much as to speak of parliaments, or so much as to mention that parliaments were again to be called.”

The king’s ministers, to let the nation see they were absolutely determined to suppress all freedom of speech, caused a prosecution to be carried on by the attorney general against three members of the House of Commons, for words spoken in that house, Anno 1628. The members pleaded to the information, that expressions in parliament ought only to be examined and punished there. This notwithstanding, *they were all three condemned as disturbers of the state*; one of these gentlemen, Sir John Eliot, was fined two thousand pounds, and sentenced to lie in prison till it was paid. His lady was denied admittance to him, even during his sickness; consequently, his punishment comprehended an additional sentence of divorce. This patriot, having endured many years imprisonment, sunk under the oppression, and died in prison: this was such a wound to the authority and rights of Parliament that, even after the restoration, the judgment was revered by Parliament.

That Englishmen of all ranks might be effectually intimidated from publishing their thoughts on any subject, except on the side of the court, his majesty’s ministers caused an information, for several libels, to be exhibited in the Star Chamber against Messrs. *Prynn*, *Burton*, and *Bastwick*. They were each of them fined five thousand pounds, and adjudged to lose their ears on the pillory, to be branded on the cheeks with hot irons, and to suffer perpetual imprisonment! Thus these three gentlemen, each of worth and quality in their several professions, viz., divinity, law, and physic, were, for no other offence than writing on controverted points of church government, exposed on public scaffolds, and stigmatized and mutilated as common signal rogues or the most ordinary malefactors.

Such corporeal punishments, inflicted with all the circumstances of cruelty and infamy, bound down all other gentlemen under a servile fear of like treatment; so that, for several years, no one durst publicly speak or write in defence of the liberties of the people; which the king’s ministers, his privy council, and his judges, had trampled under their feet. The spirit of the administration looked hideous and dreadful; the hate and resentment which the people conceived against it, for a long time lay smothered in their breasts, where those passions festered and grew venomous, and at last discharged themselves by an armed and vindictive hand.

King Charles II. aimed at the subversion of the government, but concealed his designs under a deep hypocrisy: a method which his predecessor, in the beginning of his reign, scorned to make use of. The father, who affected a high and rigid gravity, discountenanced all barefaced immorality. The son, of a gay, luxurious disposition, openly encouraged it: thus their inclinations being different, the restraint laid on some authors, and the encouragement given to others, were managed after a different manner.

In this reign a licenser was appointed for the stage and the press; no plays were encouraged but what had a tendency to debase the minds of the people. The original design of comedy was perverted; it appeared in all the shocking circumstances of immodest *double entendre*, obscure description, and lewd representation. Religion was sneered out of countenance, and public spirit ridiculed as an awkward old fashioned virtue; the fine gentleman of the comedy, though embroidered over with wit, was a consummate debauchee; and a fine lady, though set off with a brilliant imagination, was an impudent coquette. Satire, which in the hands of *Horace*, *Juvenal*, and *Boileau*, was pointed with a generous resentment against vice, now became the declared foe of virtue and innocence. As the city of London, in all ages, as well as the time we are now speaking of, was remarkable for its opposition to arbitrary power, the poets leveled all their artillery against the metropolis, in order to bring the citizens into contempt: an alderman was never introduced on the theatre but under the complicated character of a sneaking, canting hypocrite, a miser, and a cuckold; while the court-wits, with impunity, libeled the most valuable part of the nation. Other writers, of a different stamp, with great learning and gravity, endeavored to prove to the English people that slavery was *jure divino*.[^2] Thus the stage
and the press, under the direction of a licenser, became battering engines against religion, virtue, and liberty. Those who had courage enough to write in their defense, were stigmatized as schismatics, and punished as disturbers of the government.

But when the embargo on wit was taken off, *Sir Richard Steel* and *Mr. Addison* soon rescued the stage from the load of impurity it labored under with an inimitable address, they strongly recommended to our imitation the most amiable, rational manly characters; and this with so much success that I cannot suppose there is any reader to-day conversant in the writings of those gentlemen, that can taste with any tolerable relish the comedies of the once admired *Shadwell*. Vice was obliged to retire and give place to virtue: this will always be the consequence when truth has fair play: falsehood only dreads the attack, and cries out for auxiliaries: the truth never fears the encounter: she scorns the aid of the secular arm, and triumphs by her natural strength.

But, to resume the description of the reign of Charles II., the doctrine of servitude was chiefly managed by *Sir Roger Lestrange*. He had great advantages in the argument, being licenser for the press, and might have carried all before him without contradiction, if writings on the other side of the question had not been printed by stealth. The authors, whenever found, were prosecuted as seditious libelers; on all these occasions the king’s counsel, particularly *Sawyer* and *Finch*, appeared most obsequious to accomplish the ends of the court.

During this *blessed* management, the king had entered into a secret league with France to render himself absolute and enslave his subjects. This fact was discovered to the world by Dr. *Jonathan Swift*, to whom *Sir William Temple* had entrusted the publication of his works.

*Sidney*, the sworn foe of tyranny, was a gentleman of noble family, of sublime understanding and exalted courage. The ministry were resolved to remove so great an obstacle out of the way of their designs. He was prosecuted for high treason. The overt act charged in the indictment was a libel found in his private study. Mr. Finch, the king’s own solicitor-general, urged with great vehemence to this effect, “that the *imagining* the death of the king is *treason*, even while that imagination remains concealed in the mind, though the law cannot punish such secret treasonable thoughts till it arrives at the knowledge of them by some overt act. That the matter of the libel composed by Sidney was an
*imagining how to compass the death of King Charles II.*; and the writing of it was an overt act of treason, for that to write was to act. (*Scribere est agere.*)” It seems that the king’s counsel in this reign had not received the same directions as Queen Elizabeth had given hers; she told them they were to look upon themselves as not retained so much (*pro domina regina*, as *pro domina veritate*) for the power of the queen as for the power of truth.

Mr. Sidney made a strong and legal defense. He insisted that all the words in the book contained no more than general speculations on the principles of government, free for any man to write down; especially since the same are written in the parliament rolls and in the statute laws.

He argued on the injustice of applying by innuendoes, general assertions concerning principles of government, as overt acts to prove the writer was compassing the death of the king; for then no man could write of things done even by our ancestors, in defense of the constitution and freedom of England, without exposing himself to capital danger.

He denied that *scribere est agere*, but allowed that writing and publishing is to act (*Scribere et publicare est agere*), and therefore he urged that, as his book had never been published nor imparted to any person, it could not be an overt act, within the statutes of treasons, even admitting that it contained treasonable positions; that, on the contrary, it was a *covert fact*, locked up in his private study, as much concealed from the knowledge of any man as if it were locked up in the author’s mind. This was the substance of Mr. Sidney’s defense: but neither law, nor reason, nor eloquence, nor innocence ever availed where *Jefferies* sat as judge. Without troubling himself with any part of the
defense, he declared in a rage, that Sidney’s *known principles* were a *sufficient* proof of his intention to compass the death of the king.

A packed jury therefore found him guilty of high treason: great applications were made for his pardon. He was executed as a traitor.

This case is a pregnant instance of the danger that attends a law for punishing words, and of the little security the most valuable men have for their lives, in that society where a judge, by remote inferences and distant innuendoes, may construe the most innocent expressions into capital crimes. *Sidney*, the British *Brutus*, the warm, the steady friend of *liberty*; who, from an intrinsic love to mankind, left them that invaluable legacy, his immortal discourses on government, was for these very discourses murdered by the hands of lawless power.

Upon the whole, to suppress inquiries into the administration is good policy in an arbitrary government; but a free constitution and freedom of speech have such reciprocal dependance on each other, that they cannot subsist without consisting together.

[^1]: Oh Virtue! The most certain ruin.
[^2]: By divine right.